@@ -7,10 +7,12 @@ from aoa.api.iterator_base_api import IteratorBaseApi
 class ProjectApi(IteratorBaseApi):
 
     path = "/api/projects/"
+    type = "PROJECT"
 
     def _get_header_params(self):
-        header_vars = ['Accept']
-        header_vals = ['application/json']
+        # The header for project id is required for the archive/unarchive method from base_api
+        header_vars = ['AOA-Project-ID', 'Accept']
+        header_vals = [self.aoa_client.project_id, 'application/json']
 
         return self.generate_params(header_vars, header_vals)
 
@@ -61,3 +63,15 @@ class ProjectApi(IteratorBaseApi):
             header_params,
             query_params,
             project)
+
+    def is_archived(self, project_id: str):
+        """
+        returns the archived status of a project
+        Parameters:
+           project_id (str): project id to check archived status
+        Returns:
+            (bool)
+        """
+        project = self.find_by_id(project_id)
+
+        return project["archived"]
