@@ -4,10 +4,12 @@ from typing import Dict, List
 from aoa.api.iterator_base_api import IteratorBaseApi
 from aoa.api.trained_model_artefacts_api import TrainedModelArtefactsApi
 
+import uuid
 
 class TrainedModelApi(IteratorBaseApi):
 
     path = "/api/trainedModels/"
+    type = "TRAINED_MODEL"
 
     def _get_header_params(self):
         header_vars = ['AOA-Project-ID', 'Accept']
@@ -258,15 +260,20 @@ class TrainedModelApi(IteratorBaseApi):
 
         query_params = {}
 
+        import_id = uuid.uuid4()
+        metadata = trained_model.get("metadata", dict())
+        metadata["artefactImportId"] = str(import_id)
+        trained_model["metadata"] = metadata
+
+        trained_model_artefacts_api = TrainedModelArtefactsApi(self.aoa_client)
+        trained_model_artefacts_api.upload_artefacts(import_id, artefacts)
+
         response = self.aoa_client.post_request(
             self.path,
             header_params,
             query_params,
             trained_model)
 
-        trained_model_artefacts_api = TrainedModelArtefactsApi(self.aoa_client)
-        trained_model_artefacts_api.upload_artefacts(response['id'], artefacts)
-
         return response
 
     def approve(self, trained_model_id: str, note: str):
